Aihc Cli Py
===
百舸命令行工具

快速开始
---
```bash
pip install aihc-cli-py
```

测试
---
如何执行自动化测试

如何贡献
---
贡献patch流程及质量要求

版本信息
---
本项目的各版本信息和变更历史可以在[这里][changelog]查看。

维护者
---
### owners
* wangzhuyun(wangzhuyun@baidu.com)

### committers
* wangzhuyun(wangzhuyun@baidu.com)

讨论
---
百度Hi交流群：群号


[changelog]: http://icode.baidu.com/repos/baidu/aihc/aihc-cli-py/blob/master:CHANGELOG.md
